@@ -11,6 +11,7 @@
 // Copyright (C) 2012 Hib Eris <hib@hiberis.nl>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2019 Christian Persch <chpe@src.gnome.org>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -28,6 +29,7 @@
 #include <config.h>
 
 #include "FileSpec.h"
+#include "goo/gfile.h"
 
 EmbFile::EmbFile(Object &&efStream)
 {
@@ -83,7 +85,7 @@ bool EmbFile::save(const char *path) {
   FILE *f;
   bool ret;
 
-  if (!(f = fopen(path, "wb"))) {
+  if (!(f = openFile(path, "wb"))) {
     return false;
   }
   ret = save2(f);
@@ -133,11 +135,12 @@ FileSpec::FileSpec(const Object *fileSpecA)
         return;
       }
     }
-  }
 
-  obj1 = fileSpec.dictLookup("Desc");
-  if (obj1.isString())
-    desc = obj1.getString()->copy();
+    obj1 = fileSpec.dictLookup("Desc");
+    if (obj1.isString()) {
+      desc = obj1.getString()->copy();
+    }
+  }
 }
 
 FileSpec::~FileSpec()
