@@ -22,6 +22,7 @@
  * Copyright (C) 2017, 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
  * Copyright (C) 2018 Intevation GmbH <intevation@intevation.de>
  * Copyright (C) 2018, Tobias Deiminger <haxtibal@posteo.de>
+ * Copyright (C) 2018 Nelson Benítez León <nbenitezl@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -220,7 +221,7 @@ Link* PageData::convertLinkActionToLink(::LinkAction * a, DocumentData *parentDo
       // copy link file
       const QString fileName = UnicodeParsedString( g->getFileName() );
       const LinkDestinationData ldd( g->getDest(), g->getNamedDest(), parentDoc, !fileName.isEmpty() );
-      // ceate link: fileName, namedDest, object pointer
+      // create link: fileName, namedDest, object pointer
       popplerLink = new LinkGoto( linkArea, fileName, LinkDestination( ldd ) );
     }
     break;
@@ -394,28 +395,28 @@ inline TextPage *PageData::prepareTextSearch(const QString &text, Page::Rotation
   return textPage;
 }
 
-inline bool PageData::performSingleTextSearch(TextPage* textPage, QVector<Unicode> &u, double &sLeft, double &sTop, double &sRight, double &sBottom, Page::SearchDirection direction, bool sCase, bool sWords)
+inline bool PageData::performSingleTextSearch(TextPage* textPage, QVector<Unicode> &u, double &sLeft, double &sTop, double &sRight, double &sBottom, Page::SearchDirection direction, bool sCase, bool sWords, bool sDiacritics = false)
 {
   if (direction == Page::FromTop)
     return textPage->findText( u.data(), u.size(),
-           true, true, false, false, sCase, false, sWords, &sLeft, &sTop, &sRight, &sBottom );
+           true, true, false, false, sCase, sDiacritics, false, sWords, &sLeft, &sTop, &sRight, &sBottom );
   else if ( direction == Page::NextResult )
     return textPage->findText( u.data(), u.size(),
-           false, true, true, false, sCase, false, sWords, &sLeft, &sTop, &sRight, &sBottom );
+           false, true, true, false, sCase, sDiacritics, false, sWords, &sLeft, &sTop, &sRight, &sBottom );
   else if ( direction == Page::PreviousResult )
     return textPage->findText( u.data(), u.size(),
-           false, true, true, false, sCase, true, sWords, &sLeft, &sTop, &sRight, &sBottom );
+           false, true, true, false, sCase, sDiacritics, true, sWords, &sLeft, &sTop, &sRight, &sBottom );
 
   return false;
 }
 
-inline QList<QRectF> PageData::performMultipleTextSearch(TextPage* textPage, QVector<Unicode> &u, bool sCase, bool sWords)
+inline QList<QRectF> PageData::performMultipleTextSearch(TextPage* textPage, QVector<Unicode> &u, bool sCase, bool sWords, bool sDiacritics = false)
 {
   QList<QRectF> results;
   double sLeft = 0.0, sTop = 0.0, sRight = 0.0, sBottom = 0.0;
 
   while(textPage->findText( u.data(), u.size(),
-        false, true, true, false, sCase, false, sWords, &sLeft, &sTop, &sRight, &sBottom ))
+        false, true, true, false, sCase, sDiacritics, false, sWords, &sLeft, &sTop, &sRight, &sBottom ))
   {
       QRectF result;
 
@@ -533,7 +534,7 @@ QImage Page::renderToImage(double xres, double yres, int x, int y, int w, int h,
       overprintPreview = m_page->parentDoc->m_hints & Document::OverprintPreview ? true : false;
       if (overprintPreview)
       {
-        Guchar c, m, y, k;
+        unsigned char c, m, y, k;
 
         c = 255 - m_page->parentDoc->paperColor.blue();
         m = 255 - m_page->parentDoc->paperColor.red();
@@ -718,11 +719,12 @@ bool Page::search(const QString &text, double &sLeft, double &sTop, double &sRig
 {
   const bool sCase = flags.testFlag(IgnoreCase) ? false : true;
   const bool sWords = flags.testFlag(WholeWords) ? true : false;
+  const bool sDiacritics = flags.testFlag(IgnoreDiacritics) ? true : false;
 
   QVector<Unicode> u;
   TextPage *textPage = m_page->prepareTextSearch(text, rotate, &u);
 
-  const bool found = m_page->performSingleTextSearch(textPage, u, sLeft, sTop, sRight, sBottom, direction, sCase, sWords);
+  const bool found = m_page->performSingleTextSearch(textPage, u, sLeft, sTop, sRight, sBottom, direction, sCase, sWords, sDiacritics);
 
   textPage->decRefCnt();
 
@@ -747,11 +749,12 @@ QList<QRectF> Page::search(const QString &text, SearchFlags flags, Rotation rota
 {
   const bool sCase = flags.testFlag(IgnoreCase) ? false : true;
   const bool sWords = flags.testFlag(WholeWords) ? true : false;
+  const bool sDiacritics = flags.testFlag(IgnoreDiacritics) ? true : false;
 
   QVector<Unicode> u;
   TextPage *textPage = m_page->prepareTextSearch(text, rotate, &u);
 
-  const QList<QRectF> results = m_page->performMultipleTextSearch(textPage, u, sCase, sWords);
+  const QList<QRectF> results = m_page->performMultipleTextSearch(textPage, u, sCase, sWords, sDiacritics);
 
   textPage->decRefCnt();
 
